# thcli
CLI program created by taehoon. This is for studying. Do not use in production ;)


## How to use?
```bash
pip install thcli
thcli hello --name 'taehoon' --age 14 # Hello taehoon in 14 years old. 👍

# see more
thcli --help
```

## Features
1. Capitalize the greeting.
When `heLlo` is given, it will change into `Hello` capitalizing the first character.

2. Random emoji for fun!
Random emoji is added at the end!

* available emojis
- 👍
- 👎
- 🔥
